@@ -11,13 +11,14 @@ use Catalyst::Utils;
 use Path::Class qw(file dir);
 use Time::HiRes qw(tv_interval);
 use Clone qw(clone);
+use Carp 'croak';
 require Data::Dumper::Concise;
 use URI::Escape;
 
 use RapidApp;
 use Template;
 
-use Catalyst::Controller::SimpleCAS 0.994;
+use Catalyst::Controller::SimpleCAS 0.995;
 
 sub rapidapp_version { $RapidApp::VERSION }
 
@@ -98,7 +99,16 @@ before 'setup_middleware' => sub {
     '+RapidApp::Plack::Middleware'
 };
 
-
+sub application_has_root_controller {
+  my $app = shift;
+  for (keys %{ $app->components }) {
+    my $component = $app->components->{$_};
+    if ($component->can('action_namespace')) {
+      return 1 if $component->action_namespace($app) eq '';
+    }
+  }
+  return 0;
+}
 
 around 'setup_components' => sub {
 	my ($orig, $app, @args)= @_;
@@ -114,7 +124,7 @@ sub setupRapidApp {
     @{ $app->config->{ra_inject_components} || [] },
     ['RapidApp::RapidApp' => 'RapidApp']
   );
-  
+
   # Views:
   push @inject, (
     ['Catalyst::View::TT'            => 'View::RapidApp::TT'         ],
@@ -143,7 +153,11 @@ sub setupRapidApp {
   #  #  if($app->debug);
   #  push @inject,['RapidApp::Controller::DefaultRoot', 'Controller::RapidApp::Root'];
   #}
-  
+
+  croak "Please use module_root_namespace, if you install your own Root Controller"
+    if $app->application_has_root_controller
+      && !$app->config->{RapidApp}->{module_root_namespace};
+
   # Controllers:
   push @inject, (
     ['RapidApp::Controller::DefaultRoot'             => 'Controller::RapidApp::Root'             ],
@@ -152,9 +166,8 @@ sub setupRapidApp {
     ['RapidApp::Template::Controller::Dispatch'      => 'Controller::RapidApp::TemplateDispatch' ],
     ['Catalyst::Controller::SimpleCAS'               => 'Controller::SimpleCAS'                  ],
   );
-  
+
   $app->injectUnlessExist( @{$_} ) for (@inject);
-  
 };
 
 sub root_module_controller {
