@@ -14,6 +14,7 @@ use RapidApp::DBIC::Component::TableSpec;
 require Text::Glob;
 use Text::WagnerFischer qw(distance);
 use Clone qw( clone );
+use Digest::MD5 qw(md5_hex);
 
 # hackish performance tweak:
 my %match_glob_cache = ();
@@ -85,8 +86,6 @@ sub _colspec_attr_init_trigger {
 	});
 }
 
-
-
 sub BUILD {}
 after BUILD => sub {
 	my $self = shift;
@@ -589,7 +588,7 @@ sub _colspec_test($$){
 	my @parts = split(/\./,$full_colspec); 
 	my $colspec = pop @parts;
 	my $relspec = join('.',@parts);
-	
+
 	my $sep = $self->relation_sep;
 	my $prefix = $relspec;
 	$prefix =~ s/\./${sep}/g;
@@ -623,12 +622,23 @@ sub _colspec_test($$){
 	return undef;
 }
 
+#
+# colspec_test_key is used to see if _colspec_test changed, this is
+# the only relevant indicator to refetch the result for the given
+# colspec_test
+#
+use B::Deparse;
+our $colspec_test_source;
+{
+	my $deparse = B::Deparse->new;
+	$colspec_test_source = $deparse->coderef2text(\&_colspec_test);
+}
 
 # New: caching wrapper for performance:
 sub colspec_test($$){
-  my $self = shift;
-  # There may be extra args, we need to include all in the cache hashkey
-  $self->{_colspec_test_cache}{join('|',@_)} //= $self->_colspec_test(@_)
+  my ( $self, @args ) = @_;
+  my $colspec_key = join('|',@args);
+	return $self->{_colspec_test_cache}{$colspec_key} //= $self->_colspec_test(@args);
 }
 
 # returns a list of loaded column names that match the supplied colspec set
@@ -667,6 +677,8 @@ sub colspec_matches_columns {
 	return 0;
 }
 
+our $colspec_select_columns_source;
+
 # Returns a sublist of the supplied columns that match the supplied colspec set.
 # The colspec set is considered as a whole, with each column name tested against
 # the entire compiled set, which can contain both positive and negative (!) colspecs,
@@ -674,10 +686,35 @@ sub colspec_matches_columns {
 sub colspec_select_columns {
 	my $self = shift;
 	my %opt = (ref($_[0]) eq 'HASH') ? %{ $_[0] } : @_; # <-- arg as hash or hashref
-	
+
+	$self->{_colspec_select_columns_cache} = {}
+		unless defined $self->{_colspec_select_columns_cache};
+
 	my $colspecs = $opt{colspecs} or die "colspec_select_columns(): expected 'colspecs'";
 	my $columns = $opt{columns} or die "colspec_select_columns(): expected 'columns'";
-	
+	$columns = [ sort { $a cmp $b } @{$columns} ];
+	$colspecs = [ sort { $a cmp $b } @{$colspecs} ];
+
+	my $colspec_select_columns_key = join('_',
+		md5_hex(join('_',@{$colspecs})),
+		md5_hex(join('_',@{$columns})),
+	);
+
+	return @{$self->{_colspec_select_columns_cache}{$colspec_select_columns_key}}
+		if defined $self->{_colspec_select_columns_cache}{$colspec_select_columns_key};
+
+	my $cache_key;
+	if ($self->has_cache) {
+		$cache_key = join('_','colspec_select_columns_cache',
+			md5_hex($colspec_test_source.$colspec_select_columns_source),
+			md5_hex($self->ResultClass),
+			$colspec_select_columns_key,
+		);
+		my $cache_content = $self->cache->get($cache_key);
+		return @{$self->{_colspec_select_columns_cache}{$colspec_select_columns_key} = $cache_content}
+			if $cache_content;
+	}
+
 	# if best_match_look_ahead is true, the current remaining colspecs will be passed
 	# to each invocation of colspec_test which will cause it to only return a match
 	# when testing the *closest* (according to WagnerFischer edit distance) colspec
@@ -688,7 +725,7 @@ sub colspec_select_columns {
 	$columns = [ $columns ] unless (ref $columns);
 	
 	$opt{match_data} = {} unless ($opt{match_data});
-	
+
 	my %match = map { $_ => 0 } @$columns;
 	my @order = ();
 	my $i = 0;
@@ -709,7 +746,16 @@ sub colspec_select_columns {
 		}
 	}
 	
-	return uniq(grep { $match{$_} > 0 } @order);
+	my $colspec_select_columns = [ uniq(grep { $match{$_} > 0 } @order) ];
+	if ($cache_key) {
+		$self->cache->set($cache_key,$colspec_select_columns);
+	}
+	return @{$self->{_colspec_select_columns_cache}{$colspec_select_columns_key} = $colspec_select_columns};
+}
+
+{
+	my $deparse = B::Deparse->new;
+	$colspec_select_columns_source = $deparse->coderef2text(\&colspec_select_columns);
 }
 
 # Applies the original column order defined in the table Schema:
@@ -934,11 +980,11 @@ sub add_related_TableSpec {
 		relspec_prefix => $relspec_prefix,
 		include_colspec => $self->include_colspec->get_subspec($rel),
 	);
-	
+
 	$params{updatable_colspec} = $self->updatable_colspec->get_subspec($rel) || []; 
 	$params{creatable_colspec} = $self->creatable_colspec->get_subspec($rel) || [];
 	$params{no_column_colspec} = $self->no_column_colspec->get_subspec($rel) || [];
-		
+
 	%params = ( %params, %opt );
 	
 	my $class = $self->ResultClass;
@@ -1366,6 +1412,8 @@ sub resolve_dbic_rel_alias_by_column_name  {
 			my $function = $info->{function} || sub {
 				my ($self,$rel,$col,$join,$cond_data2,$name2) = @_;
 				my $sql = $info->{sql} || 'SELECT(NULL)';
+				# also see RapidApp::DBIC::Component::VirtualColumnsExt
+				$sql = $info->{sql}->($self->ResultClass, $col) if ref $sql eq 'CODE';
 				
 				# ** translate 'self.' into the relname of the current context. This
 				# should either be 'me.' or the join name. This logic is important
